import formidable = require('formidable');
import { upImgPathConfig } from '../serverConfig';
import * as userData from './../model/users';
import * as pictureData from './../model/picture';
import * as crypto from 'crypto';
import { BizError } from '../util/bizError';
import { psdForPng } from '../util/psd';
const fs = require('fs');
const path = require('path');

//上传psd文件
export async function upPsdFile(req, userId, psdType, userName, desc) {
    let {fileName, pId} = getFileName();
    let upResult:any = await up(req, fileName);
    let success = true;
    if (upResult.file) {
        let pngName = psdForPng(fileName);
        let size = upResult.file.size;
        await pictureData.addOncePic(pId, userId, userName, fileName, pngName, psdType, desc, size);
    } else {
        success = false;
        throw new BizError("上传psd错误 fileName", fileName);
    }

    return { success };
}

async function up(req, fileName) {
    let form = new formidable.IncomingForm();
    let psdUrl = path.join(__dirname.substring(0,__dirname.indexOf("out")), upImgPathConfig.psd);
    form.uploadDir = psdUrl;
    form.on('end',()=>{
        console.log("up end");
    })
    return new Promise((resolve, reject) => {
        form.parse(req, async (err, fields, files) => {
            if (err) reject(err);
            fs.rename(files.file.path, path.join(psdUrl, 'sdfa/',fileName), (err) => {
                if (err) throw new BizError("改名失败", err);
                else resolve(files);
            });
        });
    });
}


function getFileName() {
    let randomStr = Math.ceil(Math.random()* 10000000) + '' +new Date().valueOf();
    const md5 = crypto.createHash('md5');
    let fileNameMd5 = md5.update(randomStr).digest('hex');
    return {fileName:fileNameMd5+'.psd', pId:fileNameMd5};
}

export async function picList(picType) {
    let dbList = await pictureData.selectAllPicture();

    let picList = [];

    dbList.forEach(info => { 
        let {pId ,uId ,uName ,psdName ,pngName ,chartType ,createTime ,desc ,size} = info;
        picList.push({
            pId,
            uId,
            uName,
            psdName,
            pngName,
            chartType,
            createTime,
            desc,
            size
        });
    });

    return {picList}

}
